<?php 
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Premium_Banner_Widget extends Widget_Base {

	protected $templateInstance;

	public function getTemplateInstance() {
		return $this->templateInstance = premium_Template_Tags::getInstance();
	}

	public function get_name() {
		return 'premium-addon-banner';
	}

	public function get_title() {
		return esc_html__( 'Premium Banner', 'premium-addons-for-elementor' );
	}

	public function get_icon() {
		return 'pa-banner';
	}
    
	public function get_categories() {
		return [ 'premium-elements' ];
	}

	// Adding the controls fields for the premium banner
	// This will controls the animation, colors and background, dimensions etc
	protected function _register_controls() {

		$this->start_controls_section(
			'premium_banner_global_settings',
			[
				'label' 		=> esc_html__( 'Premium Banner', 'premium-addons-for-elementor' )
			]
		);
        
        $this->add_control(
			'premium_banner_image',
			[
				'label'			=> esc_html__( 'Premium Banner Image', 'premium-addons-for-elementor' ),
				'description'	=> esc_html__( 'Select an image for the Banner', 'premium-addons-for-elementor' ),
				'type'			=> Controls_Manager::MEDIA,
				'default'		=> [
					'url'	=> Utils::get_placeholder_image_src()
				],
				'show_external'	=> true
			]
		);
        
        $this->add_control(
			'premium_banner_image_bg_color',
			[
				'label' 		=> esc_html__( 'Background Color', 'premium-addons-for-elementor' ),
				'type' 			=> Controls_Manager::COLOR,
				'scheme' 		=> [
				    'type' 	=> Scheme_Color::get_type(),
				    'value' => Scheme_Color::COLOR_1,
				],
				'selectors' 	=> [
					'{{WRAPPER}} .premium_addons-banner-ib' => 'background: {{VALUE}};',
				]
			]
		);
        
         $this->add_control('premium_banner_link_url_switch',
                [
                    'label'         => esc_html__('Banner Link/URL', 'premium-addons-for-elementor'),
                    'type'          => Controls_Manager::SWITCHER,
                ]
                );

		$this->add_control(
			'premium_banner_image_link_switcher',
			[
				'label'			=> esc_html__( 'Banner custom link', 'premium-addons-for-elementor' ),
				'type'			=> Controls_Manager::SWITCHER,
				'default'		=> '',
				'description'	=> esc_html__( 'Add a custom link to the banner', 'premium-addons-for-elementor' ),
                'condition'     => [
                    'premium_banner_link_url_switch'    => 'yes',
                ],
			]
		);

		$this->add_control(
			'premium_banner_image_existing_page_link',
			[
				'label'			=> esc_html__( 'Set Existing Page Link', 'premium-addons-for-elementor' ),
				'type'			=> Controls_Manager::SELECT,
				'description'	=> esc_html__( 'Link the banner with an existing page', 'premium-addons-for-elementor' ),
				'condition'		=> [
					'premium_banner_image_link_switcher!' => 'yes',
                    'premium_banner_link_url_switch'    => 'yes',
				],
				'options'		=> $this->getTemplateInstance()->get_all_post()
			]
		);

		$this->add_control(
			'premium_banner_image_custom_link',
			[
				'label'			=> esc_html__( 'Set custom Link', 'premium-addons-for-elementor' ),
				'type'			=> Controls_Manager::URL,
				'description'	=> esc_html__( 'What custom link you want to set to banner?', 'premium-addons-for-elementor' ),
				'condition'		=> [
					'premium_banner_image_link_switcher' => 'yes',
                    'premium_banner_link_url_switch'    => 'yes',
				],
				'show_external' => false,
			]
		);

		$this->add_control(
			'premium_banner_image_link_open_new_tab',
			[
				'label'			=> esc_html__( 'Open in New Tab', 'premium-addons-for-elementor' ),
				'type'			=> Controls_Manager::SWITCHER,
				'default'		=> '',
				'description'	=> esc_html__( 'Choose if you want the link be opened in a new tab or not', 'premium-addons-for-elementor' ),
                'condition'     => [
                    'premium_banner_link_url_switch'    => 'yes',
                ],
			]
		);

		$this->add_control(
			'premium_banner_image_link_add_nofollow',
			[
				'label'			=> esc_html__( 'Add Nofollow Option to Link', 'premium-addons-for-elementor' ),
				'type'			=> Controls_Manager::SWITCHER,
				'default'		=> '',
				'description'	=> esc_html__('if you chose yes, the link will not be counted in search engines', 'premium-addons-for-elementor' ),
                'condition'     => [
                    'premium_banner_link_url_switch'    => 'yes',
                ],
			]
		);
        
        $this->add_control(
			'premium_banner_image_animation',
			[
				'label'			=> esc_html__( 'Banner Effects', 'premium-addons-for-elementor' ),
				'type'			=> Controls_Manager::SELECT,
				'default'		=> 'premium_banner_animation1',
				'description'	=> esc_html__( 'Choose a hover effect for the banner', 'premium-addons-for-elementor' ),
				'options'		=> [
					'premium_banner_animation1'		=> 'Effect 1',
					'premium_banner_animation5'		=> 'Effect 2',
					'premium_banner_animation13'	=> 'Effect 3',
					'premium_banner_animation2'		=> 'Effect 4',
					'premium_banner_animation4'		=> 'Effect 5',
					'premium_banner_animation6'		=> 'Effect 6'
				]
			]
		);
        
        $this->add_control(
			'premium_banner_height',
			[
				'label'			=> esc_html__( 'Banner Height', 'premium-addons-for-elementor' ),
				'type'			=> Controls_Manager::SELECT,
				'default'		=> 'default',
				'description'	=> esc_html__( 'Choose if you want to set a custom height for the banner or keep it as it is', 'premium-addons-for-elementor' ),
				'options'		=> [
					'default'		=> 'Default',
					'custom'		=> 'Custom',
				]
			]
		);

		$this->add_control(
			'premium_banner_custom_height',
			[
				'label'			=> esc_html__( 'Min Height', 'premium-addons-for-elementor' ),
				'type'			=> Controls_Manager::NUMBER,
				'description'	=> esc_html__( 'Set a minimum height value in pixels', 'premium-addons-for-elementor' ),
				'condition'		=> [
					'premium_banner_height' => 'custom'
				],
				'selectors'		=> [
					'{{WRAPPER}} .premium_addons-banner-ib' => 'height: {{VALUE}}px;'
				]
			]
		);

		$this->add_control(
			'premium_banner_extra_class',
			[
				'label'			=> esc_html__( 'Extra Class', 'premium-addons-for-elementor' ),
				'type'			=> Controls_Manager::TEXT
			]
		);

		
		$this->end_controls_section();

		$this->start_controls_section(
  			'premium_banner_image_section',
  			[
  				'label' => esc_html__( 'Banner Content', 'premium-addons-for-elementor' )
  			]
  		);
        
        $this->add_control(
			'premium_banner_title',
			[
				'label'			=> esc_html__( 'Title', 'premium-addons-for-elementor' ),
				'placeholder'	=> esc_html__( 'Give a title to this banner', 'premium-addons-for-elementor' ),
				'description'	=> esc_html__( 'Give a title to this banner', 'premium-addons-for-elementor' ),
				'type'			=> Controls_Manager::TEXT,
				'default'		=> esc_html__( 'Premium Banner', 'premium-addons-for-elementor' ),
				'label_block'	=> false
			]
		);
        
        $this->add_control(
			'premium_banner_title_tag',
			[
				'label'			=> esc_html__( 'Title HTML Tag', 'premium-addons-for-elementor' ),
				'description'	=> esc_html__( 'Select a heading tag for the title. Headings are defined with H1 to H6 tags', 'premium-addons-for-elementor' ),
				'type'			=> Controls_Manager::SELECT,
				'default'		=> 'h3',
				'options'       => [
                        'h1'    => 'H1',
                        'h2'    => 'H2',
                        'h3'    => 'H3',
                        'h4'    => 'H4',
                        'h5'    => 'H5',
                        'h6'    => 'H6',
                        ],
				'label_block'	=> true,
			]
		);
        
        $this->add_control(
			'premium_banner_style2_title_bg',
			[
				'label'			=> esc_html__( 'Title Background', 'premium-addons-for-elementor' ),
				'type'			=> Controls_Manager::COLOR,
				'default'       => '#f2f2f2',
				'description'	=> esc_html__( 'Choose a background color for the title', 'premium-addons-for-elementor' ),
				'condition'		=> [
					'premium_banner_image_animation' => 'premium_banner_animation5'
				],
				'selectors'     => [
				    '{{WRAPPER}} .premium_banner_animation5 .premium_addons-banner-ib-desc'    => 'background: {{VALUE}};',
			    ],
                'description_block'   => true,
			]
		);
        
        $this->add_control('premium_banner_title_text_align', 
            [
                'label'         => esc_html__('Alignment', 'premium-addons-for-elementor'),
                'type'          => Controls_Manager::CHOOSE,
                'options'       => [
                    'left'  => [
                        'title'     => esc_html__('Left', 'premium-addons-for-elementor'),
                        'icon'      => 'fa fa-align-left'
                    ],
                    'center'  => [
                        'title'     => esc_html__('Center', 'premium-addons-for-elementor'),
                        'icon'      => 'fa fa-align-center'
                    ],
                    'right'  => [
                        'title'     => esc_html__('Right', 'premium-addons-for-elementor'),
                        'icon'      => 'fa fa-align-right'
                    ],
                ],
                'selectors'     => [
                    '{{WRAPPER}} .premium_addons-banner-ib-title '   => 'text-align: {{VALUE}};',
                ]
            ]
            ); 
        
        $this->add_control(
			'premium_banner_description_hint',
			[
				'label'			=> esc_html__( 'Description', 'premium-addons-for-elementor' ),
				'type'			=> Controls_Manager::HEADING,
			]
		);
        
        $this->add_control(
			'premium_banner_description',
			[
				'label'			=> esc_html__( 'Description', 'premium-addons-for-elementor' ),
				'description'	=> esc_html__( 'Give the description to this banner', 'premium-addons-for-elementor' ),
				'type'			=> Controls_Manager::WYSIWYG,
				'default'		=> esc_html__( 'Premium Banner gives you a wide range of styles and options that you will definitely fall in love with', 'premium-addons-for-elementor' ),
				'label_block'	=> true
			]
		);
        
        $this->add_control('premium_banner_content_text_align', 
            [
                'label'         => esc_html__('Description Alignment', 'premium-addons-for-elementor'),
                'type'          => Controls_Manager::CHOOSE,
                'options'       => [
                    'left'  => [
                        'title'     => esc_html__('Left', 'premium-addons-for-elementor'),
                        'icon'      => 'fa fa-align-left'
                    ],
                    'center'  => [
                        'title'     => esc_html__('Center', 'premium-addons-for-elementor'),
                        'icon'      => 'fa fa-align-center'
                    ],
                    'right'  => [
                        'title'     => esc_html__('Right', 'premium-addons-for-elementor'),
                        'icon'      => 'fa fa-align-right'
                    ],
                ],
                'selectors'     => [
                    '{{WRAPPER}} .premium_addons-banner-ib-content'   => 'text-align: {{VALUE}};',
                ]
            ]
            );

		$this->end_controls_section();
        
        $this->start_controls_section('premium_banner_responsive_section',
            [
                'label'         => esc_html__('Responsive Settings', 'premium-addons-for-elementor'),
            ]);
        
        
        $this->add_control('premium_banner_responsive_switcher',
            [
                'label'         => esc_html__('Responsive Controls', 'premium-addons-for-elementor'),
                'type'          => Controls_Manager::SWITCHER,
                'description'   => esc_html__('Enabling Responsive Controls will hide the description text for the screen size that is specified', 'premium-addons-for-elementor')
            ]);
        
        $this->add_control('premium_banner_min_range', 
            [
                'label'     => esc_html__('Min Screen Size (PX)', 'premium-addons-for-elementor'),
                'type'      => Controls_Manager::NUMBER,
                'description'=> esc_html__('(Hint: min size for extra small screens is 1px)','premium-addons-for-elementor'),
                'default'   => 1,
                'condition' => [
                    'premium_banner_responsive_switcher'    => 'yes'
                ],
            ]);

        $this->add_control('premium_banner_max_range', 
            [
                'label'     => esc_html__('Max Screen Size (PX)', 'premium-addons-for-elementor'),
                'type'      => Controls_Manager::NUMBER,
                'description'=> esc_html__('(Hint: max size for extra small screens is 767px)','premium-addons-for-elementor'),
                'default'   => 767,
                'condition' => [
                    'premium_banner_responsive_switcher'    => 'yes'
                ],
            ]);

		$this->end_controls_section();
        
        $this->start_controls_section(
			'premium_banner_opacity_style',
			[
				'label' 		=> esc_html__( 'Image', 'premium-addons-for-elementor' ),
				'tab' 			=> Controls_Manager::TAB_STYLE
			]
		);
        
		$this->add_control(
			'premium_banner_image_opacity',
			[
				'label' => esc_html__( 'Opacity', 'premium-addons-for-elementor' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 1,
				],
				'range' => [
					'px' => [
		                'min' => 0,
		                'max' => 1,
		                'step' => .1,
		            ]
				],
				'selectors' => [
		            '{{WRAPPER}} .premium_addons-banner-ib .premium_addons-banner-ib-img' => 'opacity: {{SIZE}};',
		        ],
			]
		);


		$this->add_control(
			'premium_banner_image_hover_opacity',
			[
				'label' => esc_html__( 'Hover Opacity', 'premium-addons-for-elementor' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 1,
				],
				'range' => [
					'px' => [
		                'min' => 0,
		                'max' => 1,
		                'step' => .1,
		            ]
				],
				'selectors' => [
		            '{{WRAPPER}} .premium_addons-banner-ib .premium_addons-banner-ib-img.active' => 'opacity: {{SIZE}};',
		        ],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'premium_banner_title_style',
			[
				'label' 		=> esc_html__( 'Title', 'premium-addons-for-elementor' ),
				'tab' 			=> Controls_Manager::TAB_STYLE
			]
		);

		$this->add_control(
			'premium_banner_color_of_title',
			[
				'label' => esc_html__( 'Color', 'premium-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .premium_addons-banner-ib-desc .premium_banner_title' => 'color: {{VALUE}};'
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'premium_banner_title_typhography',
				'selector' => '{{WRAPPER}} .premium_addons-banner-ib-desc .premium_banner_title',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'premium_banner_styles_of_content',
			[
				'label' 		=> esc_html__( 'Description', 'premium-addons-for-elementor' ),
				'tab' 			=> Controls_Manager::TAB_STYLE
			]
		);

		$this->add_control(
			'premium_banner_color_of_content',
			[
				'label' => esc_html__( 'Color', 'premium-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_3,
				],
				'selectors' => [
					'{{WRAPPER}} .premium_banner .premium_banner_content' => 'color: {{VALUE}};'
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'premium_banner_content_typhography',
				'selector' => '{{WRAPPER}} .premium_banner .premium_banner_content',
				'scheme' => Scheme_Typography::TYPOGRAPHY_3,
			]
		);

		$this->end_controls_section();

	}


	protected function render() {
			$settings 	= $this->get_settings(); // All the settings values stored in $settings varaiable

			$title_tag 	= $settings[ 'premium_banner_title_tag' ];
			$title 		= $settings[ 'premium_banner_title' ];
			$full_title = '<'. $title_tag .' class="premium_addons-banner-ib-title ult-responsive premium_banner_title">' .$title. '</'.$title_tag.'>';

			$link = isset( $settings['premium_banner_image_link_switcher'] ) && $settings['premium_banner_image_link_switcher'] != '' ? $settings['premium_banner_image_custom_link']['url'] : get_permalink( $settings['premium_banner_image_existing_page_link'] );

			$link_title = $settings['premium_banner_image_link_switcher'] != 'yes' ? get_the_title( $settings['premium_banner_image_existing_page_link'] ) : '';
			$open_new_tab = $settings['premium_banner_image_link_open_new_tab'] == 'yes' ? ' target="_blank"' : '';
            $nofollow_link = $settings['premium_banner_image_link_add_nofollow'] == 'yes' ? ' rel="nofollow"' : '';
			$full_link = '<a class="premium_addons-banner-ib-link" href="'. $link .'" title="'. $link_title .'"'.$open_new_tab . $nofollow_link; '></a>';
			$animation_class = $settings['premium_banner_image_animation'];
			$extra_class = isset( $settings['premium_banner_extra_class'] ) && $settings['premium_banner_extra_class'] != '' ? ' '. $settings['premium_banner_extra_class'] : '';
			$min_height_class = $settings['premium_banner_height'] == 'custom' ? '' : '';
			$full_class = $animation_class.$extra_class.$min_height_class;
            $min_size = $settings['premium_banner_min_range'].'px';
            $max_size = $settings['premium_banner_max_range'].'px';
            
			ob_start();
		?>
            <div class="premium_banner" id="premium-banner-<?php echo esc_attr($this->get_id()); ?>">
				<div class="premium_addons-banner-ib <?php echo $full_class; ?> premium-banner-min-height">
					<?php if( isset(  $settings['premium_banner_image']['url'] ) &&  $settings['premium_banner_image']['url'] != '' ): ?>
					<img class="premium_addons-banner-ib-img" alt="null" src="<?php echo $settings['premium_banner_image']['url']; ?>">
					<?php endif; ?>
					<div class="premium_addons-banner-ib-desc" style="">
						<?php echo $full_title; ?>
						<div class="premium_addons-banner-ib-content premium_banner_content">
							<?php echo $this->parse_text_editor($settings[ 'premium_banner_description' ] ); ?>
						</div>
					</div>
					<?php 
						if( !empty( $settings['premium_banner_image_custom_link']['url'] ) || !empty($settings['premium_banner_image_existing_page_link'] ) ) {
							echo $full_link;
						}
					 ?>
				</div>
				<script>
						(function( $ ) {
							$(document).ready( function() {
								$('.premium_addons-banner-ib').hover(
									function() {
										$(this).find('.premium_addons-banner-ib-img').addClass('active');
									},
									function() {
										$(this).find('.premium_addons-banner-ib-img').removeClass('active');
									}
								);
							})
						})(jQuery);
				</script>
                                <?php if($settings['premium_banner_responsive_switcher'] == 'yes') : ?>
                <style>
                    @media(min-width: <?php echo $min_size; ?> ) and (max-width:<?php echo $max_size; ?>){
                    #premium-banner-<?php echo esc_attr($this->get_id()); ?> .premium_addons-banner-ib-content {
                        display: none;
                        }  
                    }
                </style>
                <?php endif; ?>

			</div>
		<?php $output = ob_get_clean();
		echo $output;
	}

	protected function content_template() {
	
	?>
	

	<?php
	}
}

Plugin::instance()->widgets_manager->register_widget_type( new Premium_Banner_Widget() );