<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Premium_Fancy_Text_Widget extends Widget_Base
{
    protected $templateInstance;

    public function getTemplateInstance() {
        return $this->templateInstance = premium_Template_Tags::getInstance();
    }

    public function get_name() {
        return 'premium-addon-fancy-text';
    }

    public function get_title() {
        return esc_html__('Premium Fancy Text', 'premium-addons-for-elementor');
    }

    public function get_icon() {
        return 'pa-fancy-text';
    }
    
    public function get_script_depends()
    {
        return ['typed-js','vticker-js'];
    }

    public function get_categories() {
        return [ 'premium-elements' ];
    }

    // Adding the controls fields for the premium fancy text
    // This will controls the animation, colors and background, dimensions etc
    protected function _register_controls() {

        /*Start Text Content Section*/
        $this->start_controls_section('premium_fancy_text_content',
                [
                    'label'         => esc_html__('Text Settings', 'premium-addons-for-elementor'),
                    ]
                );
        
        /*Prefix Text*/ 
        $this->add_control('premium_fancy_prefix_text',
                [
                    'label'         => esc_html__('Prefix Text', 'premium-addons-for-elementor'),
                    'type'          => Controls_Manager::TEXT,
                    'default'       => esc_html__('This is', 'premium-addons-for-elementor'),
                    'description'   => esc_html__( 'Text before Fancy text', 'premium-addons-for-elementor' ),
                    'label_block'   => true,
                ]
                );
        
        /*Fancy Text Strings*/
        $this->add_control('premium_fancy_text_strings',
                [
                    'label'         => esc_html__( 'Fancy Text Strings', 'premium-addons-for-elementor' ),
                    'type'          => Controls_Manager::REPEATER,
                    'default'       => [
                        [
                            'premium_text_strings_text_field' => esc_html__( 'Designer', 'premium-addons-for-elementor' ),
                            ],
                        [
                            'premium_text_strings_text_field' => esc_html__( 'Developer', 'premium-addons-for-elementor' ),
                            ],
                        [
                            'premium_text_strings_text_field' => esc_html__( 'Awesome', 'premium-addons-for-elementor' ),
                            ],
                        ],
                    'fields'        => [
                        [
                            'name'        => 'premium_text_strings_text_field',
                            'label'       => esc_html__( 'Fancy String', 'premium-addons-for-elementor' ),
                            'type'        => Controls_Manager::TEXT,
                            'label_block' => true,
                            ],
                        ],
                    'title_field'   => '{{{ premium_text_strings_text_field }}}',
                    ]
                );

		/*Prefix Text*/ 
        $this->add_control('premium_fancy_suffix_text',
                [
                    'label'         => esc_html__('Suffix Text', 'premium-addons-for-elementor'),
                    'type'          => Controls_Manager::TEXT,
                    'default'       => esc_html__('Text', 'premium-addons-for-elementor'),
                    'description'   => esc_html__( 'Text after Fancy text', 'premium-addons-for-elementor' ),
                    'label_block'   => true,
                ]
                );
        
        /*Text Effect*/
        $this->add_control('premium_fancy_text_effect', 
                [
                    'label'         => esc_html__('Effect', 'premium-addons-for-elementor'),
                    'type'          => Controls_Manager::SELECT,
                    'description'   => esc_html__( 'Choose an Effect', 'premium-addons-for-elementor' ),
                    'options'       => [
                        'typing'=> esc_html__('Type Writer'),
                        'slide' => esc_html__('Slide Up'),
                        ],
                    'default'       => 'typing',
                    'label_block'   => true,
                    ]
                );
        
        /*Type Speed*/
        $this->add_control('premium_fancy_text_type_speed',
                [
                    'label'         => esc_html__('Type Speed (Milliseconds)', 'premium-addons-for-elementor'),
                    'type'          => Controls_Manager::NUMBER,
                    'default'       => 30,
                    'description'   => esc_html__( 'Speed at which line progresses / Speed of typing effect.', 'premium-addons-for-elementor' ),
                    'condition'     => [
                        'premium_fancy_text_effect' => 'typing',
                        ],
                    'label_block'   => true,
                ]
                );
        
        /*Back Speed*/
        $this->add_control('premium_fancy_text_back_speed',
                [
                    'label'         => esc_html__('Back Speed (Milliseconds)', 'premium-addons-for-elementor'),
                    'type'          => Controls_Manager::NUMBER,
                    'default'       => 30,
                    'description'   => esc_html__( 'Speed of delete / backspace effect.', 'premium-addons-for-elementor' ),
                    'condition'     => [
                        'premium_fancy_text_effect' => 'typing',
                        ],
                    'label_block'   => true,
                ]
                );
        
        /*Start Delay*/
        $this->add_control('premium_fancy_text_start_delay',
                [
                    'label'         => esc_html__('Start Delay (Milliseconds)', 'premium-addons-for-elementor'),
                    'type'          => Controls_Manager::NUMBER,
                    'default'       => 30,
                    'description'   => esc_html__( 'Example - If set to 5000, the first string will appear after 5 seconds.', 'premium-addons-for-elementor' ),
                    'condition'     => [
                        'premium_fancy_text_effect' => 'typing',
                        ],
                    'label_block'   => true,
                ]
                );
        
        /*Back Delay*/
        $this->add_control('premium_fancy_text_back_delay',
                [
                    'label'         => esc_html__('Back Delay (Milliseconds)', 'premium-addons-for-elementor'),
                    'type'          => Controls_Manager::NUMBER,
                    'default'       => 30,
                    'description'   => esc_html__( 'Example - If set to 5000, the string will remain visible for 5 seconds before backspace effect.', 'premium-addons-for-elementor' ),
                    'condition'     => [
                        'premium_fancy_text_effect' => 'typing',
                        ],
                    'label_block'   => true,
                ]
                );
        
        /*Type Loop*/
        $this->add_control('premium_fancy_text_type_loop',
                [
                    'label'         => esc_html__('Loop','premium-addons-for-elementor'),
                    'type'          => Controls_Manager::SWITCHER,
                    'default'       => 'yes',
                    'condition'     => [
                        'premium_fancy_text_effect' => 'typing',
                        ],
                    ]
                );
        
        /*Show Cursor*/
        $this->add_control('premium_fancy_text_show_cursor',
                [
                    'label'         => esc_html__('Show Cursor','premium-addons-for-elementor'),
                    'type'          => Controls_Manager::SWITCHER,
                    'default'       => 'yes',
                    'condition'     => [
                        'premium_fancy_text_effect' => 'typing',
                        ],
                    ]
                );
        
        /*Cursor Text*/
        $this->add_control('premium_fancy_text_cursor_text',
                [
                    'label'         => esc_html__('Cursor Text', 'premium-addons-for-elementor'),
                    'type'          => Controls_Manager::TEXT,
                    'default'       => '|',
                    'condition'     => [
                        'premium_fancy_text_effect'     => 'typing',
                        'premium_fancy_text_show_cursor'=> 'yes',
                        ],
                    ]
                );
        
        /*Slide Up Speed*/
        $this->add_control('premium_slide_up_speed',
                [
                    'label'         => esc_html__('Animation Speed (Milliseconds)', 'premium-addons-for-elementor'),
                    'type'          => Controls_Manager::NUMBER,
                    'default'       => 200,
                    'description'   => esc_html__( 'Duration of Slide Up animation', 'premium-addons-for-elementor' ),
                    'condition'     => [
                        'premium_fancy_text_effect' => 'slide',
                        ],
                    'label_block'   => true,
                ]
                );
        
        /*Slide Up Pause Time*/
        $this->add_control('premium_slide_up_pause_time',
                [
                    'label'         => esc_html__('Pause Time (Milliseconds)', 'premium-addons-for-elementor'),
                    'type'          => Controls_Manager::NUMBER,
                    'default'       => 3000,
                    'description'   => esc_html__( 'How long the string should stay visible?', 'premium-addons-for-elementor' ),
                    'condition'     => [
                        'premium_fancy_text_effect' => 'slide',
                        ],
                    'label_block'   => true,
                ]
                );
        
        /*Slide Up Shown Items*/
        $this->add_control('premium_slide_up_shown_items',
                [
                    'label'         => esc_html__('Show Items (Milliseconds)', 'premium-addons-for-elementor'),
                    'type'          => Controls_Manager::NUMBER,
                    'default'       => 1,
                    'description'   => esc_html__( 'How many items should be visible at a time?', 'premium-addons-for-elementor' ),
                    'condition'     => [
                        'premium_fancy_text_effect' => 'slide',
                        ],
                    'label_block'   => true,
                ]
                );
        
        /*Pause on Hover*/
        $this->add_control('premium_slide_up_hover_pause',
                [
                    'label'         => esc_html__('Pause on Hover','premium-addons-for-elementor'),
                    'type'          => Controls_Manager::SWITCHER,
                    'default'       => 'no',
                    'condition'     => [
                        'premium_fancy_text_effect' => 'slide',
                        ],
                    ]
                );
       
        /*Front Text Align*/
        $this->add_responsive_control('premium_fancy_text_align',
                [
                    'label'         => esc_html__( 'Text Align', 'elementor' ),
                    'type'          => Controls_Manager::CHOOSE,
                    'options'       => [
                        'left'      => [
                            'title'=> esc_html__( 'Left', 'elementor' ),
                            'icon' => 'fa fa-align-left',
                            ],
                        'center'    => [
                            'title'=> esc_html__( 'Center', 'elementor' ),
                            'icon' => 'fa fa-align-center',
                            ],
                        'right'     => [
                            'title'=> esc_html__( 'Right', 'elementor' ),
                            'icon' => 'fa fa-align-right',
                            ],
                        ],
                    'default'       => 'center',
                    'selectors'     => [
                        '{{WRAPPER}} .premium-fancy-text-wrapper' => 'text-align: {{VALUE}};',
                        ],
                    ]
                );
        
        $this->end_controls_section();
        
        /*Start Fancy Text Settings Tab*/
        $this->start_controls_section('premium_fancy_text_style_tab',
                [
                    'label'         => esc_html__('Fancy Text', 'premium-addons-for-elementor'),
                    'tab'           => Controls_Manager::TAB_STYLE,
                ]
                );
        
        /*Fancy Text Color*/
        $this->add_control('premium_fancy_text_color',
                [
                    'label'         => esc_html__('Fancy Text Color', 'premium-addons-for-elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'scheme'        => [
                        'type'  => Scheme_Color::get_type(),
                        'value' => Scheme_Color::COLOR_1,
                    ],
                    'selectors'     => [
                        '{{WRAPPER}} .premium-fancy-text' => 'color: {{VALUE}};',
                    ]
                ]
                );
        
        /*Fancy Text Background Color*/
        $this->add_control('premium_fancy_text_background_color',
                [
                    'label'         => esc_html__('Fancy Text Background', 'premium-addons-for-elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'selectors'     => [
                        '{{WRAPPER}} .premium-fancy-text' => 'background-color: {{VALUE}};',
                    ]
                ]
                );
        
        /*Fancy Text Typography*/
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'          => 'fancy_text_typography',
                    'scheme'        => Scheme_Typography::TYPOGRAPHY_1,
                    'selector'      => '{{WRAPPER}} .premium-fancy-text',
                    ]
                );  
        
        
        
        /*End Fancy Text Settings Tab*/
        $this->end_controls_section();
        
        /*Start Prefix Suffix Text Settings Tab*/
        $this->start_controls_section('premium_prefix_suffix_style_tab',
                [
                    'label'         => esc_html__('Prefix & Suffix Text', 'premium-addons-for-elementor'),
                    'tab'           => Controls_Manager::TAB_STYLE,
                ]
                );
        
        /*Prefix Suffix Text Color*/
        $this->add_control('premium_prefix_suffix_text_color',
                [
                    'label'         => esc_html__('Prefix & Suffix Color', 'premium-addons-for-elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'scheme'        => [
                    'type'  => Scheme_Color::get_type(),
                    'value' => Scheme_Color::COLOR_2,
                    ],
                    'selectors'     => [
                        '{{WRAPPER}} .premium-prefix-text, {{WRAPPER}} .premium-suffix-text' => 'color: {{VALUE}};',
                    ]
                ]
                );
        
        /*Prefix Suffix Text Background Color*/
        $this->add_control('premium_prefix_suffix_text_background_color',
                [
                    'label'         => esc_html__('Prefix & Suffix Background', 'premium-addons-for-elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'selectors'     => [
                        '{{WRAPPER}} .premium-prefix-text, {{WRAPPER}} .premium-suffix-text' => 'background-color: {{VALUE}};',
                    ]
                ]
                );
        
        /*Prefix Suffix Typography*/
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'          => 'prefix_suffix_typography',
                    'scheme'        => Scheme_Typography::TYPOGRAPHY_1,
                    'selector'      => '{{WRAPPER}} .premium-prefix-text, {{WRAPPER}} .premium-suffix-text',
                ]
                );  
        
        /*End Prefix Suffix Text Settings Tab*/
        $this->end_controls_section();
    }

    protected function render( ) {
        // get our input from the widget settings.
        $settings = $this->get_settings();
        
        $cursor_text = addslashes($settings['premium_fancy_text_cursor_text']);
        
        
?>
    

<div class="premium-fancy-text-wrapper">
    <span class="premium-prefix-text" style="<?php if ( $settings['premium_fancy_text_effect'] === 'slide' ) : echo "vertical-align:top;"; endif; ?>"><?php echo wp_kses( ( $settings['premium_fancy_prefix_text'] ), true ); ?></span>
    
    <?php if ( $settings['premium_fancy_text_effect'] === 'typing'  ) : ?><span id="premium_fancy_text_<?php echo esc_attr( $this->get_id() ); ?>" class="premium-fancy-text" ></span>
    <?php else : ?> 
    <div id="premium_fancy_text_<?php echo esc_attr( $this->get_id() ); ?>" class="premium-fancy-text" style=' display: inline-block; text-align: center;'>
	   <ul>
            <?php foreach ( $settings['premium_fancy_text_strings'] as $item ) : ?><?php if ( ! empty( $item['premium_text_strings_text_field'] ) ) : ?><?php echo "<li>".esc_attr( $item['premium_text_strings_text_field'] )."</li>"; ?><?php endif; ?><?php endforeach; ?>
        </ul>
    </div>
    <?php endif; ?>
    <span class="premium-suffix-text" style="<?php if ( $settings['premium_fancy_text_effect'] === 'slide' ) : echo "vertical-align: top;"; endif; ?>"><?php echo wp_kses( ( $settings['premium_fancy_suffix_text'] ), true ); ?></span>
</div>

<!-- Typing Effect-->
<?php if ( $settings['premium_fancy_text_effect'] === 'typing' ) : ?> 
<script type="text/javascript">
    jQuery(document).ready(function( $ ) {
            $( "#premium_fancy_text_<?php echo esc_attr( $this->get_id() );?> " ).typed( {
                strings: [ <?php foreach ( $settings['premium_fancy_text_strings'] as $item ) : ?><?php if ( ! empty( $item['premium_text_strings_text_field'] ) ) : ?>"<?php echo esc_attr($item['premium_text_strings_text_field'] ); ?>",<?php endif; ?><?php endforeach; ?> ],
                typeSpeed: <?php  echo esc_attr( $settings['premium_fancy_text_type_speed'] ); ?>,
                backSpeed: <?php  echo esc_attr( $settings['premium_fancy_text_back_speed'] ); ?>,
                startDelay: <?php echo esc_attr( $settings['premium_fancy_text_start_delay'] ); ?>,
                backDelay: <?php echo esc_attr( $settings['premium_fancy_text_back_delay'] ); ?>,
                showCursor: <?php if( !empty( $settings['premium_fancy_text_show_cursor'] ) ) : ?> true <?php else : ?>false<?php endif; ?>,
                cursorChar: <?php echo '"' . $cursor_text . '"' ; ?>,
                loop: <?php if( !empty( $settings['premium_fancy_text_type_loop'] ) ) : ?>true<?php else : ?>false<?php endif; ?>,
                });
            });
</script>
<?php endif; ?>
<!-- Slide up Effect --> 
<?php if ( $settings['premium_fancy_text_effect'] === 'slide') : ?>
<script>
    jQuery(function( $ ) {
        $( "#premium_fancy_text_<?php echo esc_attr( $this->get_id() ); ?>").vTicker( {
        speed: <?php echo esc_attr( $settings['premium_slide_up_speed'] ); ?>,
        showItems: <?php echo esc_attr( $settings['premium_slide_up_shown_items'] ); ?>,
        pause: <?php echo esc_attr( $settings['premium_slide_up_pause_time'] ); ?>,
        mousePause : <?php if ( !empty( $settings['premium_slide_up_hover_pause'] ) ) : ?>true<?php else : ?>false<?php endif; ?>,
        direction: "up"
        });
    });
</script>
<?php endif; ?>

    <?php
    }
}
Plugin::instance()->widgets_manager->register_widget_type(new Premium_Fancy_Text_Widget());